@@ -942,7 +942,7 @@ ShotcutSettings::TimelineScrolling ShotcutSettings::timelineScrolling() const
 
 bool ShotcutSettings::timelineAutoAddTracks() const
 {
-    return settings.value("timeline/autoAddTracks", false).toBool();
+    return settings.value("timeline/autoAddTracks", true).toBool();
 }
 
 void ShotcutSettings::setTimelineAutoAddTracks(bool b)
@@ -966,7 +966,7 @@ void ShotcutSettings::setTimelineRectangleSelect(bool b)
 
 bool ShotcutSettings::timelineAdjustGain() const
 {
-    return settings.value("timeline/adjustGain", true).toBool();
+    return settings.value("timeline/adjustGain", false).toBool();
 }
 
 void ShotcutSettings::setTimelineAdjustGain(bool b)
@@ -1664,7 +1664,7 @@ QString ShotcutSettings::chromiumPath() const
     return settings.value("chromiumPath", "C:/Program Files/Google/Chrome/Application/chrome.exe")
         .toString();
 #else
-    return settings.value("chromiumPath", "chromium").toString();
+    return settings.value("chromiumPath", "/usr/bin/chromium-browser").toString();
 #endif
 }
 
@@ -1672,3 +1672,13 @@ void ShotcutSettings::setChromiumPath(const QString &path)
 {
     settings.setValue("chromiumPath", path);
 }
+
+QString ShotcutSettings::screenRecorderPath() const
+{
+    return settings.value("screenRecorderPath", "obs").toString();
+}
+
+void ShotcutSettings::setScreenRecorderPath(const QString &path)
+{
+    settings.setValue("screenRecorderPath", path);
+}
